@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2008-2021 EDF R&D
+# Copyright (C) 2008-2022 EDF R&D
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -48,15 +48,15 @@ __author__ = "Jean-Philippe ARGAUD"
 __all__ = ["New"]
 
 from daCore.Aidsm import Aidsm as _Aidsm
-from daCore.version import name, version, year, date
+from daCore.version import name, version, year, date, __version__
 
 # ==============================================================================
 class New(_Aidsm):
     """
     Generic ADAO TUI builder
     """
-    def __init__(self, name = ""):
-        _Aidsm.__init__(self, name)
+    def __init__(self, __name = ""):
+        _Aidsm.__init__(self, __name)
 
 class Gui(object):
     """
