@@ -34,11 +34,13 @@ class TemplateStorage(object):
     Classe générale de stockage de type dictionnaire étendu
     (Template)
     """
+    __slots__ = ("__preferedLanguage", "__values", "__order")
+    #
     def __init__( self, language = "fr_FR" ):
         self.__preferedLanguage = language
         self.__values           = {}
         self.__order            = -1
-
+    #
     def store( self, name = None, content = None, fr_FR = "", en_EN = "", order = "next" ):
         "D.store(k, c,  fr_FR, en_EN, o) -> Store template k and its main characteristics"
         if name is None or content is None:
@@ -53,29 +55,29 @@ class TemplateStorage(object):
             'en_EN'  : str(en_EN),
             'order'  : int(self.__order),
             }
-
+    #
     def keys(self):
         "D.keys() -> list of D's keys"
         __keys = sorted(self.__values.keys())
         return __keys
-
+    #
     def __contains__(self, name):
         "D.__contains__(k) -> True if D has a key k, else False"
         return name in self.__values
-
+    #
     def __len__(self):
         "x.__len__() <==> len(x)"
         return len(self.__values)
-
+    #
     def __getitem__(self, name=None ):
         "x.__getitem__(y) <==> x[y]"
         return self.__values[name]['content']
-
+    #
     def getdoc(self, name = None, lang = "fr_FR"):
         "D.getdoc(k, l) -> Return documentation of key k in language l"
         if lang not in self.__values[name]: lang = self.__preferedLanguage
         return self.__values[name][lang]
-
+    #
     def keys_in_presentation_order(self):
         "D.keys_in_presentation_order() -> list of D's keys in presentation order"
         __orders = []
