@@ -27,9 +27,9 @@ __author__ = "Jean-Philippe ARGAUD"
 __all__ = []
 
 name     = "ADAO"
-version  = "9.9.0.1"
+version  = "9.10.0.1"
 year     = "2022"
-date     = "lundi 02 mai 2022, 12:12:12 (UTC+0100)"
+date     = "lundi 12 décembre 2022, 12:12:12 (UTC+0100)"
 
 longname = name + ", a module for Data Assimilation and Optimization"
 cata     = "V" + version.replace(".","_")
