@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2008-2021 EDF R&D
+# Copyright (C) 2008-2022 EDF R&D
 #
 # This file is part of SALOME ADAO module
 #
@@ -27,8 +27,7 @@
 """
 # Modules Python
 # print "passage dans la surcharge de configuration pour Adao"
-import os, sys, string, types, re
-import traceback
+import os
 from PyQt5.QtGui  import *
 
 # Modules Eficas
